@@ -41,13 +41,14 @@ from octohook.models import (
     _optional,
     ShortInstallation,
     Enterprise,
+    Thread,
 )
 
 
 class BaseWebhookEvent:
     payload: dict
     action: Optional[str] = None
-    sender: User
+    sender: Optional[User]
     repository: Optional[Repository] = None
     organization: Optional[Organization] = None
     enterprise: Optional[Enterprise] = None
@@ -55,7 +56,7 @@ class BaseWebhookEvent:
     def __init__(self, payload: dict):
         self.payload = payload
         self.action = payload.get("action")
-        self.sender = User(payload.get("sender"))
+        self.sender = _optional(payload, "sender", User)
 
         # Not present in GitHubAppAuthorizationEvent, InstallationEvent, SponsorshipEvent
         try:
@@ -552,6 +553,20 @@ class PullRequestReviewCommentEvent(BaseWebhookEvent):
         self.changes = _optional(payload, "changes", RawDict)
 
 
+class PullRequestReviewThreadEvent(BaseWebhookEvent):
+    """
+    https://developer.github.com/v3/activity/events/types/#pullrequestreviewthreadevent
+    """
+
+    pull_request: PullRequest
+    thread: Thread
+
+    def __init__(self, payload: dict):
+        super().__init__(payload)
+        self.pull_request = PullRequest(payload.get("pull_request"))
+        self.thread = Thread(payload.get("thread"))
+
+
 class PushEvent(BaseWebhookEvent):
     """
     https://developer.github.com/v3/activity/events/types/#pushevent
@@ -804,6 +819,7 @@ class WebhookEvent(Enum):
     PULL_REQUEST = "pull_request"
     PULL_REQUEST_REVIEW = "pull_request_review"
     PULL_REQUEST_REVIEW_COMMENT = "pull_request_review_comment"
+    PULL_REQUEST_REVIEW_THREAD = "pull_request_review_thread"
     PUSH = "push"
     PROJECT_CARD = "project_card"
     PROJECT_COLUMN = "project_column"
@@ -867,6 +883,7 @@ class WebhookEventAction(Enum):
     REOPENED = "reopened"
     REREQUESTED = "rerequested"
     RESOLVE = "resolve"
+    RESOLVED = "resolved"
     REQUESTED = "requested"
     REQUESTED_ACTION = "requested_action"
     REVIEW_REQUESTED = "review_requested"
@@ -884,6 +901,7 @@ class WebhookEventAction(Enum):
     UNLOCKED = "unlocked"
     UNPINNED = "unpinned"
     UNPUBLISHED = "unpublished"
+    UNRESOLVED = "unresolved"
     UPDATED = "updated"
 
 
@@ -920,6 +938,7 @@ event_map = {
     WebhookEvent.PULL_REQUEST: PullRequestEvent,
     WebhookEvent.PULL_REQUEST_REVIEW: PullRequestReviewEvent,
     WebhookEvent.PULL_REQUEST_REVIEW_COMMENT: PullRequestReviewCommentEvent,
+    WebhookEvent.PULL_REQUEST_REVIEW_THREAD: PullRequestReviewThreadEvent,
     WebhookEvent.PUSH: PushEvent,
     WebhookEvent.PROJECT_CARD: ProjectCardEvent,
     WebhookEvent.PROJECT_COLUMN: ProjectColumnEvent,
